"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDefaultBehaviors = createDefaultBehaviors;
const cc_1 = require("@zwave-js/cc");
const ZWavePlusCC_1 = require("@zwave-js/cc/ZWavePlusCC");
const ZWaveProtocolCC_1 = require("@zwave-js/cc/ZWaveProtocolCC");
const core_1 = require("@zwave-js/core");
const Basic_1 = require("./mockCCBehaviors/Basic");
const BinarySensor_1 = require("./mockCCBehaviors/BinarySensor");
const BinarySwitch_1 = require("./mockCCBehaviors/BinarySwitch");
const ColorSwitch_1 = require("./mockCCBehaviors/ColorSwitch");
const Configuration_1 = require("./mockCCBehaviors/Configuration");
const EnergyProduction_1 = require("./mockCCBehaviors/EnergyProduction");
const ManufacturerSpecific_1 = require("./mockCCBehaviors/ManufacturerSpecific");
const Meter_1 = require("./mockCCBehaviors/Meter");
const MultiChannel_1 = require("./mockCCBehaviors/MultiChannel");
const MultilevelSensor_1 = require("./mockCCBehaviors/MultilevelSensor");
const Notification_1 = require("./mockCCBehaviors/Notification");
const ScheduleEntryLock_1 = require("./mockCCBehaviors/ScheduleEntryLock");
const SoundSwitch_1 = require("./mockCCBehaviors/SoundSwitch");
const ThermostatMode_1 = require("./mockCCBehaviors/ThermostatMode");
const ThermostatSetpoint_1 = require("./mockCCBehaviors/ThermostatSetpoint");
const UserCode_1 = require("./mockCCBehaviors/UserCode");
const WindowCovering_1 = require("./mockCCBehaviors/WindowCovering");
const respondToRequestNodeInfo = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC
            instanceof ZWaveProtocolCC_1.ZWaveProtocolCCRequestNodeInformationFrame) {
            const cc = new ZWaveProtocolCC_1.ZWaveProtocolCCNodeInformationFrame(self.host, {
                nodeId: self.id,
                ...self.capabilities,
                supportedCCs: [...self.implementedCCs]
                    // Basic CC must not be included in the NIF
                    .filter(([ccId]) => ccId !== core_1.CommandClasses.Basic)
                    // Only include supported CCs
                    .filter(([, info]) => info.isSupported)
                    .map(([ccId]) => ccId),
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToVersionCCCommandClassGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.VersionCCCommandClassGet) {
            const endpoint = receivedCC.endpointIndex === 0
                ? self
                : self.endpoints.get(receivedCC.endpointIndex);
            if (!endpoint)
                return;
            let version = 0;
            for (const ep of [self, ...self.endpoints.values()]) {
                const info = ep.implementedCCs.get(receivedCC.requestedCC);
                if (info?.version) {
                    version = info.version;
                    break;
                }
            }
            // Basic CC is always supported implicitly
            if (version === 0 && receivedCC.requestedCC === core_1.CommandClasses.Basic) {
                version = 1;
            }
            const cc = new cc_1.VersionCCCommandClassReport(self.host, {
                nodeId: self.id,
                endpoint: "index" in endpoint ? endpoint.index : undefined,
                requestedCC: receivedCC.requestedCC,
                ccVersion: version,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToZWavePlusCCGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof ZWavePlusCC_1.ZWavePlusCCGet) {
            const cc = new ZWavePlusCC_1.ZWavePlusCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                zwavePlusVersion: 2,
                nodeType: cc_1.ZWavePlusNodeType.Node,
                roleType: self.capabilities.isListening
                    ? cc_1.ZWavePlusRoleType.AlwaysOnSlave
                    : self.capabilities.isFrequentListening
                        ? cc_1.ZWavePlusRoleType.SleepingListeningSlave
                        : cc_1.ZWavePlusRoleType.SleepingReportingSlave,
                installerIcon: 0x0000,
                userIcon: 0x0000,
            });
            return { action: "sendCC", cc, ackRequested: true };
        }
    },
};
// TODO: We should handle this more generically:
const respondToS0ZWavePlusCCGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.SecurityCCCommandEncapsulation
            && receivedCC.encapsulated instanceof ZWavePlusCC_1.ZWavePlusCCGet) {
            let cc = new ZWavePlusCC_1.ZWavePlusCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                zwavePlusVersion: 2,
                nodeType: cc_1.ZWavePlusNodeType.Node,
                roleType: self.capabilities.isListening
                    ? cc_1.ZWavePlusRoleType.AlwaysOnSlave
                    : self.capabilities.isFrequentListening
                        ? cc_1.ZWavePlusRoleType.SleepingListeningSlave
                        : cc_1.ZWavePlusRoleType.SleepingReportingSlave,
                installerIcon: 0x0000,
                userIcon: 0x0000,
            });
            cc = cc_1.SecurityCC.encapsulate(self.host, cc);
            return { action: "sendCC", cc, ackRequested: true };
        }
    },
};
const respondToS2ZWavePlusCCGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.Security2CCMessageEncapsulation
            && receivedCC.encapsulated instanceof ZWavePlusCC_1.ZWavePlusCCGet) {
            let cc = new ZWavePlusCC_1.ZWavePlusCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                zwavePlusVersion: 2,
                nodeType: cc_1.ZWavePlusNodeType.Node,
                roleType: self.capabilities.isListening
                    ? cc_1.ZWavePlusRoleType.AlwaysOnSlave
                    : self.capabilities.isFrequentListening
                        ? cc_1.ZWavePlusRoleType.SleepingListeningSlave
                        : cc_1.ZWavePlusRoleType.SleepingReportingSlave,
                installerIcon: 0x0000,
                userIcon: 0x0000,
            });
            cc = cc_1.Security2CC.encapsulate(self.host, cc);
            return { action: "sendCC", cc };
        }
    },
};
/** Predefined default behaviors that are required for interacting with the Mock Controller correctly */
function createDefaultBehaviors() {
    return [
        respondToRequestNodeInfo,
        ...MultiChannel_1.MultiChannelCCHooks,
        ...MultiChannel_1.MultiChannelCCBehaviors,
        respondToVersionCCCommandClassGet,
        respondToZWavePlusCCGet,
        respondToS0ZWavePlusCCGet,
        respondToS2ZWavePlusCCGet,
        ...Basic_1.BasicCCBehaviors,
        ...BinarySensor_1.BinarySensorCCBehaviors,
        ...BinarySwitch_1.BinarySwitchCCBehaviors,
        ...ColorSwitch_1.ColorSwitchCCBehaviors,
        ...Configuration_1.ConfigurationCCBehaviors,
        ...EnergyProduction_1.EnergyProductionCCBehaviors,
        ...ManufacturerSpecific_1.ManufacturerSpecificCCBehaviors,
        ...Meter_1.MeterCCBehaviors,
        ...MultilevelSensor_1.MultilevelSensorCCBehaviors,
        ...Notification_1.NotificationCCBehaviors,
        ...ScheduleEntryLock_1.ScheduleEntryLockCCBehaviors,
        ...SoundSwitch_1.SoundSwitchCCBehaviors,
        ...ThermostatMode_1.ThermostatModeCCBehaviors,
        ...ThermostatSetpoint_1.ThermostatSetpointCCBehaviors,
        ...UserCode_1.UserCodeCCBehaviors,
        ...WindowCovering_1.WindowCoveringCCBehaviors,
    ];
}
//# sourceMappingURL=MockNodeBehaviors.js.map