"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BasicCCBehaviors = void 0;
const BasicCC_1 = require("@zwave-js/cc/BasicCC");
const safe_1 = require("@zwave-js/core/safe");
const STATE_KEY_PREFIX = "Basic_";
const StateKeys = {
    currentValue: `${STATE_KEY_PREFIX}currentValue`,
};
const respondToBasicGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof BasicCC_1.BasicCCGet) {
            // Do not respond if BasicCC is not explicitly listed as supported
            if (!self.implementedCCs.get(safe_1.CommandClasses.Basic)?.isSupported) {
                return;
            }
            const cc = new BasicCC_1.BasicCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                currentValue: (self.state.get(StateKeys.currentValue)
                    ?? 0),
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToBasicSet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof BasicCC_1.BasicCCSet) {
            self.state.set(StateKeys.currentValue, receivedCC.targetValue);
            return { action: "ok" };
        }
    },
};
exports.BasicCCBehaviors = [respondToBasicGet, respondToBasicSet];
//# sourceMappingURL=Basic.js.map