"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BinarySensorCCBehaviors = void 0;
const cc_1 = require("@zwave-js/cc");
const core_1 = require("@zwave-js/core");
const defaultCapabilities = {
    supportedSensorTypes: [],
};
const respondToBinarySensorSupportedGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.BinarySensorCCSupportedGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses["Binary Sensor"], receivedCC.endpointIndex),
            };
            const cc = new cc_1.BinarySensorCCSupportedReport(self.host, {
                nodeId: controller.host.ownNodeId,
                supportedSensorTypes: capabilities.supportedSensorTypes,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToBinarySensorGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.BinarySensorCCGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses["Binary Sensor"], receivedCC.endpointIndex),
            };
            let sensorType;
            if (receivedCC.sensorType == undefined
                || receivedCC.sensorType === cc_1.BinarySensorType.Any) {
                // If the sensor type is not specified, use the first supported one
                sensorType = capabilities.supportedSensorTypes[0];
            }
            else {
                sensorType = receivedCC.sensorType;
            }
            if (sensorType != undefined) {
                const value = capabilities.getValue?.(sensorType) ?? false;
                const cc = new cc_1.BinarySensorCCReport(self.host, {
                    nodeId: controller.host.ownNodeId,
                    type: sensorType,
                    value,
                });
                return { action: "sendCC", cc };
            }
            return { action: "stop" };
        }
    },
};
exports.BinarySensorCCBehaviors = [
    respondToBinarySensorSupportedGet,
    respondToBinarySensorGet,
];
//# sourceMappingURL=BinarySensor.js.map