"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ColorSwitchCCBehaviors = void 0;
const cc_1 = require("@zwave-js/cc");
const ColorSwitchCC_1 = require("@zwave-js/cc/ColorSwitchCC");
const safe_1 = require("@zwave-js/core/safe");
const shared_1 = require("@zwave-js/shared");
const defaultCapabilities = {
    colorComponents: {},
};
const STATE_KEY_PREFIX = "ColorSwitch_";
const StateKeys = {
    component: (component) => `${STATE_KEY_PREFIX}${(0, shared_1.getEnumMemberName)(cc_1.ColorComponent, component)}`,
};
const respondToColorSwitchSupportedGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof ColorSwitchCC_1.ColorSwitchCCSupportedGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Color Switch"], receivedCC.endpointIndex),
            };
            const cc = new ColorSwitchCC_1.ColorSwitchCCSupportedReport(self.host, {
                nodeId: controller.host.ownNodeId,
                supportedColorComponents: Object.keys(capabilities.colorComponents).map((c) => parseInt(c)),
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToColorSwitchSet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof ColorSwitchCC_1.ColorSwitchCCSet) {
            for (const [key, value] of Object.entries(receivedCC.colorTable)) {
                const component = cc_1.ColorComponentMap[key];
                self.state.set(StateKeys.component(component), value);
            }
            return { action: "ok" };
        }
    },
};
const respondToColorSwitchGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof ColorSwitchCC_1.ColorSwitchCCGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Color Switch"], receivedCC.endpointIndex),
            };
            const component = receivedCC.colorComponent;
            if (component in capabilities.colorComponents) {
                const cc = new ColorSwitchCC_1.ColorSwitchCCReport(self.host, {
                    nodeId: controller.host.ownNodeId,
                    colorComponent: component,
                    currentValue: (self.state.get(StateKeys.component(component))
                        ?? capabilities.colorComponents[component]
                        ?? 0),
                });
                return { action: "sendCC", cc };
            }
            else {
                return { action: "stop" };
            }
        }
    },
};
const respondToColorSwitchStartLevelChange = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof ColorSwitchCC_1.ColorSwitchCCStartLevelChange) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Color Switch"], receivedCC.endpointIndex),
            };
            const component = receivedCC.colorComponent;
            if (component in capabilities.colorComponents) {
                // TODO: A proper simulation should gradually transition the value. We just set it to the target value.
                self.state.set(StateKeys.component(component), receivedCC.direction === "up" ? 255 : 0);
                return { action: "ok" };
            }
            else {
                return { action: "fail" };
            }
        }
    },
};
const respondToColorSwitchStopLevelChange = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof ColorSwitchCC_1.ColorSwitchCCStopLevelChange) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Color Switch"], receivedCC.endpointIndex),
            };
            const component = receivedCC.colorComponent;
            if (component in capabilities.colorComponents) {
                return { action: "ok" };
            }
            else {
                return { action: "fail" };
            }
        }
    },
};
exports.ColorSwitchCCBehaviors = [
    respondToColorSwitchSupportedGet,
    respondToColorSwitchSet,
    respondToColorSwitchGet,
    respondToColorSwitchStartLevelChange,
    respondToColorSwitchStopLevelChange,
];
//# sourceMappingURL=ColorSwitch.js.map