"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnergyProductionCCBehaviors = void 0;
const cc_1 = require("@zwave-js/cc");
const EnergyProductionCC_1 = require("@zwave-js/cc/EnergyProductionCC");
const safe_1 = require("@zwave-js/core/safe");
const shared_1 = require("@zwave-js/shared");
const defaultCapabilities = {
    values: {
        Power: {
            value: 0,
            scale: 0,
        },
        "Production Total": {
            value: 0,
            scale: 0,
        },
        "Production Today": {
            value: 0,
            scale: 0,
        },
        "Total Time": {
            value: 0,
            scale: 0,
        },
    },
};
const respondToEnergyProductionGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof EnergyProductionCC_1.EnergyProductionCCGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Energy Production"], receivedCC.endpointIndex),
            };
            const result = capabilities.values[(0, shared_1.getEnumMemberName)(cc_1.EnergyProductionParameter, receivedCC.parameter)];
            const cc = new EnergyProductionCC_1.EnergyProductionCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                parameter: receivedCC.parameter,
                value: result?.value ?? 0,
                scale: (0, cc_1.getEnergyProductionScale)(receivedCC.parameter, result?.scale ?? 0),
            });
            return { action: "sendCC", cc };
        }
    },
};
exports.EnergyProductionCCBehaviors = [respondToEnergyProductionGet];
//# sourceMappingURL=EnergyProduction.js.map