"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MeterCCBehaviors = exports.defaultCapabilities = void 0;
const cc_1 = require("@zwave-js/cc");
const core_1 = require("@zwave-js/core");
exports.defaultCapabilities = {
    meterType: 0x01, // Electric
    supportedScales: [0x00], // kWh
    supportedRateTypes: [cc_1.RateType.Consumed],
    supportsReset: true,
};
const respondToMeterSupportedGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MeterCCSupportedGet) {
            const capabilities = {
                ...exports.defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses.Meter, receivedCC.endpointIndex),
            };
            const cc = new cc_1.MeterCCSupportedReport(self.host, {
                nodeId: controller.host.ownNodeId,
                type: capabilities.meterType,
                supportedScales: capabilities.supportedScales,
                supportedRateTypes: capabilities.supportedRateTypes,
                supportsReset: capabilities.supportsReset,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToMeterGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MeterCCGet) {
            const capabilities = {
                ...exports.defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses.Meter, receivedCC.endpointIndex),
            };
            const scale = receivedCC.scale
                ?? capabilities.supportedScales[0];
            const rateType = receivedCC.rateType
                ?? capabilities.supportedRateTypes[0]
                ?? cc_1.RateType.Consumed;
            const value = capabilities.getValue?.(scale, rateType) ?? {
                value: 0,
                deltaTime: 0,
            };
            const normalizedValue = typeof value === "number"
                ? {
                    value,
                    deltaTime: 0,
                }
                : value;
            const cc = new cc_1.MeterCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                type: capabilities.meterType,
                scale,
                rateType,
                ...normalizedValue,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToMeterReset = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MeterCCReset) {
            const capabilities = {
                ...exports.defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses.Meter, receivedCC.endpointIndex),
            };
            const cc = receivedCC;
            if (cc.type != undefined
                && cc.scale != undefined
                && cc.rateType != undefined
                && cc.targetValue != undefined) {
                capabilities.onReset?.({
                    scale: cc.scale,
                    rateType: cc.rateType,
                    targetValue: cc.targetValue,
                });
            }
            else {
                capabilities.onReset?.();
            }
            return { action: "ok" };
        }
    },
};
exports.MeterCCBehaviors = [
    respondToMeterSupportedGet,
    respondToMeterGet,
    respondToMeterReset,
];
//# sourceMappingURL=Meter.js.map