"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiChannelCCBehaviors = exports.MultiChannelCCHooks = void 0;
const cc_1 = require("@zwave-js/cc");
const core_1 = require("@zwave-js/core");
const encapsulateMultiChannelCC = {
    transformIncomingCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultiChannelCCCommandEncapsulation) {
            // The existing machinery interprets endpointIndex from the view
            // of the controller, but we are the end node here, so re-interpret
            // the destination as the endpoint index
            receivedCC.encapsulated.endpointIndex = receivedCC
                .destination;
            receivedCC = receivedCC.encapsulated;
        }
        return receivedCC;
    },
    transformResponse(controller, self, receivedCC, response) {
        if (response.action === "sendCC"
            && receivedCC instanceof cc_1.CommandClass
            && receivedCC.isEncapsulatedWith(core_1.CommandClasses["Multi Channel"])
            && !response.cc.isEncapsulatedWith(core_1.CommandClasses["Multi Channel"])) {
            const multiChannelEncap = receivedCC.getEncapsulatingCC(core_1.CommandClasses["Multi Channel"]);
            if (!multiChannelEncap)
                return response;
            // FIXME: Consider V1 of the CC
            const destination = multiChannelEncap.endpointIndex;
            const source = multiChannelEncap
                .destination;
            response.cc = new cc_1.MultiChannelCCCommandEncapsulation(self.host, {
                nodeId: response.cc.nodeId,
                encapsulated: response.cc,
                endpoint: source,
                destination,
            });
        }
        return response;
    },
};
const respondToMultiChannelCCEndPointGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultiChannelCCEndPointGet) {
            const cc = new cc_1.MultiChannelCCEndPointReport(self.host, {
                nodeId: controller.host.ownNodeId,
                countIsDynamic: false,
                identicalCapabilities: false,
                individualCount: self.endpoints.size,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToMultiChannelCCEndPointFind = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultiChannelCCEndPointFind) {
            const request = receivedCC;
            const cc = new cc_1.MultiChannelCCEndPointFindReport(self.host, {
                nodeId: controller.host.ownNodeId,
                genericClass: request.genericClass,
                specificClass: request.specificClass,
                foundEndpoints: [...self.endpoints.keys()],
                reportsToFollow: 0,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToMultiChannelCCCapabilityGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultiChannelCCCapabilityGet) {
            const endpoint = self.endpoints.get(receivedCC.requestedEndpoint);
            const cc = new cc_1.MultiChannelCCCapabilityReport(self.host, {
                nodeId: controller.host.ownNodeId,
                endpointIndex: endpoint.index,
                genericDeviceClass: endpoint?.capabilities.genericDeviceClass
                    ?? self.capabilities.genericDeviceClass,
                specificDeviceClass: endpoint?.capabilities.specificDeviceClass
                    ?? self.capabilities.specificDeviceClass,
                isDynamic: false,
                wasRemoved: false,
                supportedCCs: [...endpoint.implementedCCs.keys()]
                    // Basic CC must not be included in the NIF
                    .filter((ccId) => ccId !== core_1.CommandClasses.Basic),
            });
            return { action: "sendCC", cc };
        }
    },
};
exports.MultiChannelCCHooks = [
    encapsulateMultiChannelCC,
];
exports.MultiChannelCCBehaviors = [
    respondToMultiChannelCCEndPointGet,
    respondToMultiChannelCCEndPointFind,
    respondToMultiChannelCCCapabilityGet,
];
//# sourceMappingURL=MultiChannel.js.map