"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultilevelSensorCCBehaviors = void 0;
const cc_1 = require("@zwave-js/cc");
const core_1 = require("@zwave-js/core");
const defaultCapabilities = {
    sensors: {}, // none
};
const respondToMultilevelSensorGetSupportedSensor = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultilevelSensorCCGetSupportedSensor) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses["Multilevel Sensor"], receivedCC.endpointIndex),
            };
            const cc = new cc_1.MultilevelSensorCCSupportedSensorReport(self.host, {
                nodeId: controller.host.ownNodeId,
                supportedSensorTypes: Object.keys(capabilities.sensors).map((t) => parseInt(t)),
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToMultilevelSensorGetSupportedScale = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultilevelSensorCCGetSupportedScale) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses["Multilevel Sensor"], receivedCC.endpointIndex),
            };
            const sensorType = receivedCC.sensorType;
            const supportedScales = capabilities.sensors[sensorType]?.supportedScales ?? [];
            const cc = new cc_1.MultilevelSensorCCSupportedScaleReport(self.host, {
                nodeId: controller.host.ownNodeId,
                sensorType,
                supportedScales,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToMultilevelSensorGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof cc_1.MultilevelSensorCCGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses["Multilevel Sensor"], receivedCC.endpointIndex),
            };
            const firstSupportedSensorType = Object.keys(capabilities.sensors).length > 0
                ? parseInt(Object.keys(capabilities.sensors)[0])
                : undefined;
            const sensorType = receivedCC.sensorType
                ?? firstSupportedSensorType
                ?? 1;
            const scale = receivedCC.scale
                ?? capabilities.sensors[sensorType].supportedScales[0]
                ?? 0;
            const value = capabilities.getValue?.(sensorType, scale) ?? 0;
            const cc = new cc_1.MultilevelSensorCCReport(self.host, {
                nodeId: controller.host.ownNodeId,
                type: sensorType,
                scale,
                value,
            });
            return { action: "sendCC", cc };
        }
    },
};
exports.MultilevelSensorCCBehaviors = [
    respondToMultilevelSensorGetSupportedSensor,
    respondToMultilevelSensorGetSupportedScale,
    respondToMultilevelSensorGet,
];
//# sourceMappingURL=MultilevelSensor.js.map