"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotificationCCBehaviors = void 0;
const NotificationCC_1 = require("@zwave-js/cc/NotificationCC");
const core_1 = require("@zwave-js/core");
const defaultCapabilities = {
    supportsV1Alarm: false,
    notificationTypesAndEvents: {}, // none
};
const respondToNotificationSupportedGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof NotificationCC_1.NotificationCCSupportedGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses.Notification, receivedCC.endpointIndex),
            };
            const cc = new NotificationCC_1.NotificationCCSupportedReport(self.host, {
                nodeId: controller.host.ownNodeId,
                supportsV1Alarm: capabilities.supportsV1Alarm,
                supportedNotificationTypes: Object.keys(capabilities.notificationTypesAndEvents).map((t) => parseInt(t)),
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToNotificationEventSupportedGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof NotificationCC_1.NotificationCCEventSupportedGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(core_1.CommandClasses.Notification, receivedCC.endpointIndex),
            };
            if (receivedCC.notificationType
                in capabilities.notificationTypesAndEvents) {
                const cc = new NotificationCC_1.NotificationCCEventSupportedReport(self.host, {
                    nodeId: controller.host.ownNodeId,
                    notificationType: receivedCC.notificationType,
                    supportedEvents: capabilities.notificationTypesAndEvents[receivedCC.notificationType],
                });
                return { action: "sendCC", cc };
            }
            return { action: "stop" };
        }
    },
};
exports.NotificationCCBehaviors = [
    respondToNotificationSupportedGet,
    respondToNotificationEventSupportedGet,
];
//# sourceMappingURL=Notification.js.map