"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SoundSwitchCCBehaviors = void 0;
const SoundSwitchCC_1 = require("@zwave-js/cc/SoundSwitchCC");
const safe_1 = require("@zwave-js/core/safe");
const defaultCapabilities = {
    defaultToneId: 1,
    defaultVolume: 0,
    tones: [],
};
const STATE_KEY_PREFIX = "SoundSwitch_";
const StateKeys = {
    defaultToneId: `${STATE_KEY_PREFIX}defaultToneId`,
    defaultVolume: `${STATE_KEY_PREFIX}defaultVolume`,
};
const respondToSoundSwitchConfigurationGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof SoundSwitchCC_1.SoundSwitchCCConfigurationGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Sound Switch"], receivedCC.endpointIndex),
            };
            const cc = new SoundSwitchCC_1.SoundSwitchCCConfigurationReport(self.host, {
                nodeId: controller.host.ownNodeId,
                defaultToneId: self.state.get(StateKeys.defaultToneId)
                    ?? capabilities.defaultToneId,
                defaultVolume: self.state.get(StateKeys.defaultVolume)
                    ?? capabilities.defaultVolume,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToSoundSwitchConfigurationSet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof SoundSwitchCC_1.SoundSwitchCCConfigurationSet) {
            self.state.set(StateKeys.defaultToneId, receivedCC.defaultToneId);
            self.state.set(StateKeys.defaultVolume, receivedCC.defaultVolume);
            return { action: "ok" };
        }
    },
};
const respondToSoundSwitchToneNumberGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof SoundSwitchCC_1.SoundSwitchCCTonesNumberGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Sound Switch"], receivedCC.endpointIndex),
            };
            const cc = new SoundSwitchCC_1.SoundSwitchCCTonesNumberReport(self.host, {
                nodeId: controller.host.ownNodeId,
                toneCount: capabilities.tones.length,
            });
            return { action: "sendCC", cc };
        }
    },
};
const respondToSoundSwitchToneInfoGet = {
    handleCC(controller, self, receivedCC) {
        if (receivedCC instanceof SoundSwitchCC_1.SoundSwitchCCToneInfoGet) {
            const capabilities = {
                ...defaultCapabilities,
                ...self.getCCCapabilities(safe_1.CommandClasses["Sound Switch"], receivedCC.endpointIndex),
            };
            const tone = capabilities.tones[receivedCC.toneId - 1];
            if (tone) {
                const cc = new SoundSwitchCC_1.SoundSwitchCCToneInfoReport(self.host, {
                    nodeId: controller.host.ownNodeId,
                    toneId: receivedCC.toneId,
                    ...tone,
                });
                return { action: "sendCC", cc };
            }
            return { action: "stop" };
        }
    },
};
exports.SoundSwitchCCBehaviors = [
    respondToSoundSwitchConfigurationGet,
    respondToSoundSwitchConfigurationSet,
    respondToSoundSwitchToneNumberGet,
    respondToSoundSwitchToneInfoGet,
];
//# sourceMappingURL=SoundSwitch.js.map