"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.meters = void 0;
exports.getMeter = getMeter;
exports.getAllMeters = getAllMeters;
exports.getMeterName = getMeterName;
exports.getMeterScale = getMeterScale;
exports.getUnknownMeterScale = getUnknownMeterScale;
exports.getAllMeterScales = getAllMeterScales;
const safe_1 = require("@zwave-js/shared/safe");
exports.meters = Object.freeze({
    [0x01]: {
        name: "Electric",
        scales: {
            [0x00]: {
                label: "kWh",
                unit: "kWh",
            },
            [0x01]: {
                label: "kVAh",
                unit: "kVAh",
            },
            [0x02]: {
                label: "W",
                unit: "W",
            },
            [0x03]: {
                label: "Pulse count",
            },
            [0x04]: {
                label: "V",
                unit: "V",
            },
            [0x05]: {
                label: "A",
                unit: "A",
            },
            [0x06]: {
                label: "Power Factor",
            },
            [0x07]: {
                label: "kVar",
                unit: "kVar",
            },
            [0x08]: {
                label: "kVarh",
                unit: "kVarh",
            },
        },
    },
    [0x02]: {
        name: "Gas",
        scales: {
            [0x00]: {
                label: "Cubic meters",
                unit: "m³",
            },
            [0x01]: {
                label: "Cubic feet",
                unit: "ft³",
            },
            [0x03]: {
                label: "Pulse count",
            },
        },
    },
    [0x03]: {
        name: "Water",
        scales: {
            [0x00]: {
                label: "Cubic meters",
                unit: "m³",
            },
            [0x01]: {
                label: "Cubic feet",
                unit: "ft³",
            },
            [0x02]: {
                label: "US gallons",
                unit: "gal",
            },
            [0x03]: {
                label: "Pulse count",
            },
        },
    },
    [0x04]: {
        name: "Heating",
        scales: {
            [0x00]: {
                label: "kWh",
                unit: "kWh",
            },
        },
    },
    [0x05]: {
        name: "Cooling",
        scales: {
            [0x00]: {
                label: "kWh",
                unit: "kWh",
            },
        },
    },
});
/** Returns the meter definition for the given key */
function getMeter(type) {
    const meter = exports.meters[type];
    // @ts-expect-error Undefined is valid if the meter type is not found
    if (!meter)
        return;
    return {
        key: type,
        ...meter,
    };
}
/** Returns all meter definitions including their scales */
function getAllMeters() {
    return Object.entries(exports.meters)
        .map(([key, value]) => ({ key: parseInt(key, 10), ...value }));
}
function getMeterName(meterType) {
    return getMeter(meterType)?.name
        ?? `UNKNOWN (${(0, safe_1.num2hex)(meterType)})`;
}
/** Returns a meter scale definition for the given meter type and scale key */
function getMeterScale(type, scale) {
    const meter = getMeter(type);
    // @ts-expect-error Undefined is valid if the meter is not found
    if (!meter)
        return;
    const scaleDef = (meter?.scales)[scale];
    // @ts-expect-error Undefined is valid if the scale is not found
    if (!scaleDef)
        return;
    return {
        key: scale,
        ...scaleDef,
    };
}
/** Returns a meter scale definition for a scale that is not known */
function getUnknownMeterScale(key) {
    return {
        key,
        label: `Unknown (${(0, safe_1.num2hex)(key)})`,
    };
}
/** Returns all scales of a given meter */
function getAllMeterScales(meterType) {
    const meter = getMeter(meterType);
    if (!meter)
        return;
    return Object.entries(meter.scales)
        .map(([key, value]) => ({ key: parseInt(key, 10), ...value }));
}
//# sourceMappingURL=Meters.js.map