"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MOCK_FRAME_ACK_TIMEOUT = exports.MockZWaveFrameType = void 0;
exports.createMockZWaveRequestFrame = createMockZWaveRequestFrame;
exports.createMockZWaveAckFrame = createMockZWaveAckFrame;
exports.unlazyMockZWaveFrame = unlazyMockZWaveFrame;
var MockZWaveFrameType;
(function (MockZWaveFrameType) {
    MockZWaveFrameType[MockZWaveFrameType["Request"] = 0] = "Request";
    MockZWaveFrameType[MockZWaveFrameType["ACK"] = 1] = "ACK";
})(MockZWaveFrameType || (exports.MockZWaveFrameType = MockZWaveFrameType = {}));
function createMockZWaveRequestFrame(payload, options = {}) {
    const { repeaters = [], ackRequested = true } = options;
    return {
        type: MockZWaveFrameType.Request,
        repeaters,
        ackRequested,
        payload,
    };
}
function createMockZWaveAckFrame(options = {}) {
    const { repeaters = [], ack = true, failedHop } = options;
    return {
        type: MockZWaveFrameType.ACK,
        repeaters,
        ack,
        failedHop,
    };
}
function unlazyMockZWaveFrame(frame) {
    if (frame.type === MockZWaveFrameType.ACK)
        return frame;
    let payload = frame.payload;
    if (typeof payload === "function") {
        payload = payload();
    }
    return {
        ...frame,
        payload,
    };
}
/** How long a Mock Node gets to ack a Z-Wave frame */
exports.MOCK_FRAME_ACK_TIMEOUT = 1000;
//# sourceMappingURL=MockZWaveFrame.js.map